@@ -7,7 +7,6 @@ import time
 from datetime import datetime
 
 import pandas as pd
-import requests
 from python_graphql_client import GraphqlClient
 
 
@@ -51,7 +50,7 @@ class USwapper:
 
                 except ConnectionError:
                     print( 'Connection error' )
-                    time.sleep( 5 )
+                    time.sleep( 1 )
 
                 else:
                     return price
@@ -61,7 +60,7 @@ class USwapper:
 
     def gettokenaddress(self, symbol):
         ass = self.getassets()
-        addv = ass[ass['symboil'] == symbol].index.values
+        addv = ass[ass['symbol'] == symbol].index.values
         return addv[0]
 
     def getlastupdated(self):
@@ -71,17 +70,23 @@ class USwapper:
 
         return f'{value:%Y-%m-%d %H:%M:%S}'
 
-    @staticmethod
-    def getassets():
+    def getassets(self):
+        i = 0
+        ass = pd.DataFrame()
         while True:
+            i += 1
             try:
-                response = requests.get( 'https://api.uniswap.info/v2/assets' )
-                response.raise_for_status()
+                res = self.client.execute( f'{{tokens(first: 1000, skip:{(i-1)*1000}){{'
+                                           f'id symbol name decimals}}}}' )['data']['tokens']
+                if len(res) == 0:
+                    break
+
             except ConnectionError:
+
                 print( 'Connection Error..' )
-                time.sleep( 10 )
+                time.sleep( 1 )
             else:
-                ass = pd.DataFrame( response.json() ).T
-                ass.set_index( 'id', inplace=True )
-                ass.drop( columns=['maker_fee', 'taker_fee'], inplace=True )
-                return ass
+                ass = ass.append(res)
+
+        ass.set_index('id', inplace=True)
+        return ass
